;;;; launch-setup.scm
;;;; Kon Lovett, Sep '06

(use srfi-1 srfi-13 posix)
(use miscmacros osprocess)

;;;

(define-parameter chicken-setup-proxy ""
  (lambda (x)
    (if (string? x)
      x
      (chicken-setup-proxy) ) ) )

(define-parameter chicken-setup-host ""
  (lambda (x)
    (if (string? x)
      x
      (chicken-setup-host) ) ) )

;;;

(define (optional-chicken-setup-string val)
  (if (string-null? val) '("") `(" " ,val)) )

(define (optional-chicken-setup-option nam val)
  (if (string-null? val) '("") `(" " ,nam " " ,val)) )

(define (make-chicken-setup-commandline opts)
  (string-concatenate
    `("chicken-setup"
      ,@(optional-chicken-setup-string opts)
      ,@(optional-chicken-setup-option "-host" (chicken-setup-host))
      ,@(optional-chicken-setup-option "-proxy" (chicken-setup-proxy)))) )

(define (run-setup opts thunk)
  (handle-exceptions exp
    #f
    (receive [pid in out err osp]
             (osprocess (make-chicken-setup-commandline opts) #:reap? #f)
      (begin0
        (cons
          (with-input-from-port in thunk)
          (with-input-from-port err thunk))
        (osprocess-wait osp)))) )

;;;

(define (chicken-repository-list)
  (run-setup "-fetch-tree" read) )

(define (chicken-install-extension extn)
  (run-setup (conc "-dont-ask " extn) read-lines) )

(define (chicken-uninstall-extension extn)
  (run-setup (conc "-uninstall " extn) read-lines) )
