;;;; remote-launch-test.scm

(use testbase testbase-output-human)
(use remote-launch-client)
(use posix)

;;;

(define-expect-unary list?)

(define *launchd-pid* #f)

(define-test start-server-test "Launchd Server"
  (expect-set! *launchd-pid* (process-run "chicken-launchd"
                                          (if (eq? 'driven (test::run-mode)) '() '("--debug"))))
  (expect-zero (sleep 1))
)

(define-test launchd-test "Launchd Client"
  (initial
    (define client #f)
  )

  (expect-set! client (make-remote-launch-client "foo"))

  (test/suite "Information"
    (expect-list (remote-platform-request client))
    (expect-list (remote-repository-list-request client))
  )

  (test/suite "Install"
    (expect-list (remote-extension-information-request client 'codewalk))
    (expect-list (remote-install-request client 'codewalk))
    (expect-list (remote-extension-information-request client 'codewalk))
  )

  (test/suite "Spawn" (
      [info #f]
      [pid #f]
    )

    (expect-set! info (remote-spawn-request client "sleep" '(60)))
    (expect-set! pid (car info))
    (expect-equal `(,pid #f) (remote-exit-request client pid))
    (expect-equal `(,pid (#f 15 ,(car (cadr info)))) (remote-shutdown-request client pid))
  )
)

(define-test kill-server-test "Kill The Launch Server Test"
  (expect-success (process-signal *launchd-pid*))
  (side-effect (set! *launchd-pid* #f))
)

(test::for-each (cut test::styler-set! <> test::output-style-human))
(run-test "Remote Launch Tests")
